import * as i0 from '@angular/core';
import { Pipe, NgModule } from '@angular/core';

var HttpMethod;
(function (HttpMethod) {
    HttpMethod["GET"] = "GET";
    HttpMethod["POST"] = "POST";
    HttpMethod["PUT"] = "PUT";
    HttpMethod["PATCH"] = "PATCH";
    HttpMethod["DELETE"] = "DELETE";
})(HttpMethod || (HttpMethod = {}));

/**
 * Pipe a HypermediaResource to check for specific authorizations.
 */
class AuthorizationPipe {
    /**
     * Checks whether the permission for the desired action on the desired resource is available in the given HypermediaResource.
     * @param hypermediaResource The current resource with the references (_links) to other potential resources.
     * @param name The name of the hypermedia link you are looking for.
     * @param action The action you are looking for. Can be one specific http method, or one wildcard of 'read' (GET) or 'write' (POST, PUT, PATCH, DELETE).
     */
    transform(hypermediaResource, name, action) {
        if (!hypermediaResource?._links) {
            return false;
        }
        const methods = hypermediaResource?._links[name]?.methods;
        if (!methods || methods.length < 1) {
            return false;
        }
        if (action === 'read') {
            return methods.includes(HttpMethod.GET);
        }
        if (action === 'write') {
            return (methods.includes(HttpMethod.POST) ||
                methods.includes(HttpMethod.PUT) ||
                methods.includes(HttpMethod.PATCH) ||
                methods.includes(HttpMethod.DELETE));
        }
        if (action === 'readonly') {
            return (this.transform(hypermediaResource, name, 'read') && !this.transform(hypermediaResource, name, 'write'));
        }
        return methods.includes(action?.toUpperCase());
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: AuthorizationPipe, deps: [], target: i0.ɵɵFactoryTarget.Pipe }); }
    static { this.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "14.0.0", version: "16.2.12", ngImport: i0, type: AuthorizationPipe, name: "authorization" }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: AuthorizationPipe, decorators: [{
            type: Pipe,
            args: [{
                    name: 'authorization',
                }]
        }] });
/**
 * The negated variant of the @AuthorizationPipe.
 * An easy way to check for missing Authorizations in html views (e. g. [disabled]="hypermediaResource|noAuthorization:'endpoint':'write'").
 */
class NoAuthorizationPipe {
    constructor(authorizationPipe) {
        this.authorizationPipe = authorizationPipe;
    }
    transform(resource, name, action) {
        return !this.authorizationPipe.transform(resource, name, action);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: NoAuthorizationPipe, deps: [{ token: AuthorizationPipe }], target: i0.ɵɵFactoryTarget.Pipe }); }
    static { this.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "14.0.0", version: "16.2.12", ngImport: i0, type: NoAuthorizationPipe, name: "noAuthorization" }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: NoAuthorizationPipe, decorators: [{
            type: Pipe,
            args: [{
                    name: 'noAuthorization',
                }]
        }], ctorParameters: function () { return [{ type: AuthorizationPipe }]; } });

class HateauthModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: HateauthModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "16.2.12", ngImport: i0, type: HateauthModule, declarations: [AuthorizationPipe, NoAuthorizationPipe], exports: [AuthorizationPipe, NoAuthorizationPipe] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: HateauthModule, providers: [AuthorizationPipe, NoAuthorizationPipe] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: HateauthModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [AuthorizationPipe, NoAuthorizationPipe],
                    imports: [],
                    exports: [AuthorizationPipe, NoAuthorizationPipe],
                    providers: [AuthorizationPipe, NoAuthorizationPipe],
                }]
        }] });

/*
 * Public API Surface of hateauth-angular
 */

/**
 * Generated bundle index. Do not edit.
 */

export { AuthorizationPipe, HateauthModule, HttpMethod, NoAuthorizationPipe };
//# sourceMappingURL=spicysources-hateauth-angular.mjs.map
