import { PipeTransform } from '@angular/core';
import { HypermediaResource } from './hateauth.model';
import * as i0 from "@angular/core";
/**
 * Pipe a HypermediaResource to check for specific authorizations.
 */
export declare class AuthorizationPipe implements PipeTransform {
    /**
     * Checks whether the permission for the desired action on the desired resource is available in the given HypermediaResource.
     * @param hypermediaResource The current resource with the references (_links) to other potential resources.
     * @param name The name of the hypermedia link you are looking for.
     * @param action The action you are looking for. Can be one specific http method, or one wildcard of 'read' (GET) or 'write' (POST, PUT, PATCH, DELETE).
     */
    transform(hypermediaResource: HypermediaResource, name: string, action: string): boolean;
    static ɵfac: i0.ɵɵFactoryDeclaration<AuthorizationPipe, never>;
    static ɵpipe: i0.ɵɵPipeDeclaration<AuthorizationPipe, "authorization", false>;
}
/**
 * The negated variant of the @AuthorizationPipe.
 * An easy way to check for missing Authorizations in html views (e. g. [disabled]="hypermediaResource|noAuthorization:'endpoint':'write'").
 */
export declare class NoAuthorizationPipe implements PipeTransform {
    private readonly authorizationPipe;
    constructor(authorizationPipe: AuthorizationPipe);
    transform(resource: HypermediaResource, name: string, action: string): boolean;
    static ɵfac: i0.ɵɵFactoryDeclaration<NoAuthorizationPipe, never>;
    static ɵpipe: i0.ɵɵPipeDeclaration<NoAuthorizationPipe, "noAuthorization", false>;
}
